==> haskell-contravariant-extras-0.3.5.3-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-contravariant-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 contravariant-extras
version:              0.3.5.3
visibility:           public
id:                   contravariant-extras-0.3.5.3-BGlPAAS49KHDJXTGlRLp3u
key:                  contravariant-extras-0.3.5.3-BGlPAAS49KHDJXTGlRLp3u
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/contravariant-extras
synopsis:             Extras for the "contravariant" package
category:             Control
abi:                  13027509579cd1b1b3a135edf66944b5
exposed:              True
exposed-modules:
    Contravariant.Extras Contravariant.Extras.Contrazip
    Contravariant.Extras.ContrazipLifting Contravariant.Extras.Op
    Contravariant.Extras.Op.Contrazip

hidden-modules:       Contravariant.Extras.Prelude Contravariant.Extras.TH
import-dirs:          /usr/lib/ghc-9.0.2/site-local/contravariant-extras-0.3.5.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/contravariant-extras-0.3.5.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-contravariant-extras
hs-libraries:         HScontravariant-extras-0.3.5.3-BGlPAAS49KHDJXTGlRLp3u
depends:
    base-4.15.1.0 contravariant-1.5.5-FtJyCLyWfutGN2UWoJs8qd
    template-haskell-2.17.0.0
    template-haskell-compat-v0208-0.1.9.1-7l0MVNX5ZP87vABkCF62xQ

haddock-interfaces:
    /usr/share/doc/haskell-contravariant-extras/html/contravariant-extras.haddock

haddock-html:         /usr/share/doc/haskell-contravariant-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-contravariant-extras-0.3.5.3-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-contravariant-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 contravariant-extras
version:              0.3.5.3
visibility:           public
id:                   contravariant-extras-0.3.5.3-LpchVnShsLR7WYk4qtOxKD
key:                  contravariant-extras-0.3.5.3-LpchVnShsLR7WYk4qtOxKD
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/contravariant-extras
synopsis:             Extras for the "contravariant" package
category:             Control
abi:                  c28934dd838f0fe0d65b595c5577a97a
exposed:              True
exposed-modules:
    Contravariant.Extras Contravariant.Extras.Contrazip
    Contravariant.Extras.ContrazipLifting Contravariant.Extras.Op
    Contravariant.Extras.Op.Contrazip

hidden-modules:       Contravariant.Extras.Prelude Contravariant.Extras.TH
import-dirs:          /usr/lib/ghc-9.0.2/site-local/contravariant-extras-0.3.5.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/contravariant-extras-0.3.5.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-contravariant-extras
hs-libraries:         HScontravariant-extras-0.3.5.3-LpchVnShsLR7WYk4qtOxKD
depends:
    base-4.15.1.0 contravariant-1.5.5-FtJyCLyWfutGN2UWoJs8qd
    template-haskell-2.17.0.0
    template-haskell-compat-v0208-0.1.9.2-7QuGd69Nysp590aYJ6z7Ut

haddock-interfaces:
    /usr/share/doc/haskell-contravariant-extras/html/contravariant-extras.haddock

haddock-html:         /usr/share/doc/haskell-contravariant-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
